from django.urls import path

from blogorama.api import views

urlpatterns = [
    # path("posts/", views.PostlListAPIView.as_view(), name="blogorama-post-list"),
    # path(
    #     "post/<slug:the_slug>/",
    # ),
]



from rest_framework import generics

from blogorama.models import Post

# from blogorama.api.serializers import PostSerializer


# class PostlListAPIView(generics.ListAPIView):
# queryset = Post.objects.active()
#     serializer_class = SampleModelSerializer



from django.urls import path

from blogorama import views

urlpatterns = [
    path("posts/", views.PostlListAPIView.as_view(), name="blogorama-post-list"),
    path(
        "post/<slug:slug>/",
        views.PostDetailView.as_view(),
        name="blogorama-post",
    ),
]



from django.views.generic import ListView, DetailView
from .settings import Config
from .models import Post


def toc_generator():
    # TODO: Update this format with real data
    return [{"year": "2023", "months": [{"name": "January", "posts": [{"title": "post1", "url": "/blog/"}]}]}]


class PostlListAPIView(ListView):
    queryset = Post.objects.active()
    # extra_context = {"toc": toc_generator()}
    paginate_by = Config.BLOG_PAGINATION


class PostDetailView(DetailView):
    model = Post



import uuid

from django.conf import settings
from django.db import models
from django.utils.translation import gettext as _
from django.urls import reverse
from django.contrib.sites.models import Site
from .utils import unique_slugify


class StateChoices(models.IntegerChoices):
    PUBLISHED = 0, _("Published")
    DRAFT = 1, _("Draft")
    ARCHIVED = 2, _("Archived")


class FlagIssueChoices(models.IntegerChoices):
    OFF_TOPIC = 0, _("Off Topic")
    SPAM = 10, _("Spam")
    INAPPROPRIATE = 20, _("Inappropriate")


class RatingChoices(models.IntegerChoices):
    ONE = 1, _("1")
    TWO = 2, _("2")
    THREE = 3, _("3")
    FOUR = 4, _("4")
    FIVE = 5, _("5")


class EncodingChoices(models.IntegerChoices):
    # PLAIN_TEXT = 0, _("Plain Text")
    MARKDOWN = 1, _("Markdown")


"""
Wrapped choice collection in a function so it can be set by the developer without triggering a new
migration generation, which can wreak havoc if there are updates and additions. Using the tuple as
an argument bakes the values into the migration.
"""


class ActiveManager(models.Manager):
    def active(self):
        return self.filter(active=True)


class Post(models.Model):
    """The original posted article"""

    sites = models.ManyToManyField(Site, help_text=_("Set which sites this post is available on"))
    uuid = models.UUIDField(default=uuid.uuid4, editable=False, unique=True)  # Used in response tracking
    created = models.DateField(_("Created"), auto_now_add=True)
    updated = models.DateField(_("Updated"), auto_now=True)

    title = models.CharField(_("Title"), max_length=120, help_text=_("Headline for the post."))
    slug = models.SlugField(_("Slug"), blank=True)

    release_date = models.DateField(
        _("Updated"), auto_now_add=True
    )  # Defaults to the created date.  Can be set to a later date for future publication.

    banner_image = models.ImageField(  # Need to process and rename the file to make sure there are no clashes
        _("Banner"),
        upload_to="blog/post/",
        height_field=1200,
        width_field=1800,
        max_length=1800,
        blank=True,
        null=True,
    )
    banner_alt = models.CharField(_("Banner Alt Tag String"), max_length=125, blank=True, null=True)

    author = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_posts"
    )
    language = models.CharField(_("Language Code"), max_length=7, choices=settings.LANGUAGES)
    content = models.TextField(_("Content"))
    encoding_format = models.IntegerField(
        _("Encoding Format"), default=EncodingChoices.MARKDOWN, choices=EncodingChoices.choices
    )
    state = models.IntegerField(
        _("State"),
        default=StateChoices.DRAFT,
        choices=StateChoices.choices,
        help_text="What state is the writing in?",
    )
    active = models.BooleanField(_("Active"), help_text="Auto managed field based on state criteria when saved.")
    rating = models.IntegerField(_("Rating"), default=0)  # Calcuate an average of all the Ratings
    rating_count = models.IntegerField(_("Rating Count"), default=0)  # "cache" total Ratings cast
    sticky = models.IntegerField(
        _("Sticky"),
        default=0,
        help_text=_(
            "Give the blog posts a sticky value to sort to the top of the list of posts.  Higher value becomes higher in the list."
        ),
    )
    locked = models.BooleanField(_("Locked"), help_text=_("Can not add Comments and Replies."))
    hide_responses = models.BooleanField(_("Hide Responses"), help_text=_("Hide responses in display."))
    parent = models.ForeignKey(
        "self",
        verbose_name=_("Parent"),
        on_delete=models.CASCADE,
        related_name="responses",
        blank=True,
        null=True,
        help_text=_("For detailed responses for use in How-To support threads.  Not used in Blogs."),
    )

    # Custom Manager
    objects = ActiveManager()

    class Meta:
        verbose_name = _("Post")
        verbose_name_plural = _("Posts")
        ordering = (
            "sticky",
            "created",
        )

    def save(self, **kwargs):
        if self.state == 0:
            self.active = True
        else:
            self.active = False
        unique_slugify(self, self.title)  # Needs to be unique accross all sites
        super(Post, self).save(**kwargs)

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return reverse("blogorama-post", kwargs={"slug": self.slug})

    # TODO: Autotag based on text in title & content if setting is enabled.  Tasks should be queued and backgrounded.


class Tag(models.Model):
    """Tags for the Blog Post"""

    name = models.CharField(_("Tag Name"), max_length=50)
    language = models.CharField(_("Language Code"), max_length=7, choices=settings.LANGUAGES)
    active = models.BooleanField(_("Active"))
    author = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_post_tags"
    )
    posts = models.ManyToManyField(Post, verbose_name=_("Posts"))
    approved = models.BooleanField(_("Approved"), help_text=_("Check if approved for use when approval is required."))
    related = models.ManyToManyField(
        "self",
        verbose_name=_("Related"),
        help_text="Used to connect tags that are the same but in different languages.",
    )

    objects = ActiveManager()

    class Meta:
        verbose_name = _("Tag")
        verbose_name_plural = _("Tags")

    def __str__(self):
        return self.name


class TagSuggestion(models.Model):
    """
    Used for suggesting tags based on ones used
    """

    tag = models.ForeignKey(Tag, verbose_name=_("Tag"), on_delete=models.CASCADE, related_name="referrals")
    suggestion = models.ForeignKey(
        Tag, verbose_name=_("Suggested Tag"), on_delete=models.CASCADE, related_name="suggestions"
    )
    score = models.IntegerField(_("Score"), help_text=_("How relevent the suggested tag is to the connected tag"))


class Comment(models.Model):
    """User Response to the Article"""

    uuid = models.UUIDField(default=uuid.uuid4, editable=False, unique=True)
    created = models.DateField(_("Created"), auto_now_add=True)
    updated = models.DateField(_("Updated"), auto_now=True)
    author = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_comments"
    )
    language = models.CharField(_("Language Code"), max_length=7, choices=settings.LANGUAGES)
    content = models.TextField(_("Content"))
    encoding = models.IntegerField(
        _("Encoding Format"), default=EncodingChoices.MARKDOWN, choices=EncodingChoices.choices
    )
    up_vote = models.IntegerField(_("Up Vote"), default=0, help_text=_("Calculated value of all Votes"))
    up_vote_count = models.IntegerField(
        _("Up Vote Count"), default=0, help_text=_("Calculated total of Votes cast")
    )  # "cache" total Votes cast
    state = models.IntegerField(
        _("State"), default=StateChoices.DRAFT, choices=StateChoices.choices
    )  # What state is the writing in?
    solution = models.BooleanField(
        _("Solution"), help_text=_("This will tag a comment as an accepted solution if used.")
    )
    parent = models.ForeignKey(
        "self",
        verbose_name=_("Parent"),
        on_delete=models.CASCADE,
        related_name="children",
        blank=True,
        null=True,
        help_text=_("For threading comments, no parent is a top level comment"),
    )
    objects = ActiveManager()

    class Meta:
        verbose_name = _("Comment")
        verbose_name_plural = _("Comments")
        ordering = (
            "up_vote",
            "created",
        )

    def __str__(self):
        return self.name

    def calculate_votes(self):
        total_positive = 1
        total_negative = 1
        self.up_vote = total_positive - total_negative
        self.up_vote_count = total_positive + total_negative


class Vote(models.Model):
    """Up or down vote for the comment"""

    updated = models.DateField(_("Updated"), auto_now=True)
    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_comment_votes"
    )
    upvote = models.BooleanField(_("Up-Vote"), help_text=_("Checked it's an up-vote, unchecked it's a down-vote"))
    comments = models.ForeignKey(
        Comment, verbose_name=_("Comment"), on_delete=models.CASCADE, related_name="blog_comment_votes"
    )

    objects = ActiveManager()

    class Meta:
        verbose_name = _("Vote")
        verbose_name_plural = _("Votes")

    def __str__(self):
        return self.name


class Rating(models.Model):
    """On a scale of 1-5, how good is the blog?"""

    active = models.BooleanField(_("Active"))
    created = models.DateField(_("Created"), auto_now_add=True)
    updated = models.DateField(_("Updated"), auto_now=True)
    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_post_ratings"
    )
    value = models.SmallIntegerField(_("Vote Value"), choices=RatingChoices.choices, default=RatingChoices.THREE)
    post = models.ForeignKey(Post, verbose_name=_("Blog Post"), on_delete=models.CASCADE, related_name="ratings")

    objects = ActiveManager()

    class Meta:
        verbose_name = _("Rating")
        verbose_name_plural = _("Ratings")

    def calculate_rating(self):
        total_ratings_cast = self.post.ratings.count()  # Get a count of all ratings cast
        ratings_sum = 300
        self.rating = ratings_sum / total_ratings_cast
        self.rating_count = total_ratings_cast

    def __str__(self):
        return self.name


class Save(models.Model):
    """Save a blog post to an archive for reading later"""

    created = models.DateField(_("Created"), auto_now_add=True)
    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_saves"
    )
    blog = models.ForeignKey(Post, verbose_name=_("Blog Post"), on_delete=models.CASCADE, related_name="blog_saves")

    class Meta:
        verbose_name = _("Archive")
        verbose_name_plural = _("Archives")

    def __str__(self):
        return self.name


class Flag(models.Model):
    """For flaging moderator attention; issues from minor to serious"""

    created = models.DateField(_("Created"), auto_now_add=True)
    updated = models.DateField(_("Updated"), auto_now=True)
    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_comment_flags"
    )
    description = models.TextField(_("Description"))  # Description of the issue
    issue = models.IntegerField(_("Issue"), default=FlagIssueChoices.OFF_TOPIC, choices=FlagIssueChoices.choices)
    comments = models.ForeignKey(
        Comment, verbose_name=_("Comment Flagged"), on_delete=models.CASCADE, related_name="comment_flags"
    )

    class Meta:
        verbose_name = _("Flag")
        verbose_name_plural = _("Flags")

    def __str__(self):
        return self.name


class PostFlag(models.Model):
    """For flaging moderator attention; issues from minor to serious"""

    created = models.DateField(_("Created"), auto_now_add=True)
    updated = models.DateField(_("Updated"), auto_now=True)
    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_post_flags"
    )
    description = models.TextField(_("Description"))  # Description of the issue
    issue = models.IntegerField(_("Issue"), default=FlagIssueChoices.OFF_TOPIC, choices=FlagIssueChoices.choices)
    post = models.ForeignKey(Post, verbose_name=_("Post Flagged"), on_delete=models.CASCADE, related_name="post_flags")

    class Meta:
        verbose_name = _("Flag")
        verbose_name_plural = _("Flags")

    def __str__(self):
        return self.name


class Ban(models.Model):
    """
    This is to flag a user as being banned to post a comment for a given period of time or
    indefinately.  They will be able to still read the posts and comments even if banned,
    just not participate in commentary.
    """

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, verbose_name=_("User"), on_delete=models.CASCADE, related_name="blog_comment_bans"
    )
    description = models.TextField(_("Content"), help_text=_("Description of the ban."))
    created = models.DateField(_("Created"), auto_now_add=True)
    expiration = models.DateField(_("Expiration"), blank=True, null=True)
    indefinite = models.BooleanField(_("Indefinitely Banned"))

    class Meta:
        verbose_name = _("Ban")
        verbose_name_plural = _("Bans")

    def __str__(self):
        return self.name



# Generated by Django 4.1.6 on 2023-02-07 20:37

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.CreateModel(
            name="Comment",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("uuid", models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ("created", models.DateField(auto_now_add=True, verbose_name="Created")),
                ("updated", models.DateField(auto_now=True, verbose_name="Updated")),
                (
                    "language",
                    models.CharField(
                        choices=[
                            ("af", "Afrikaans"),
                            ("ar", "Arabic"),
                            ("ar-dz", "Algerian Arabic"),
                            ("ast", "Asturian"),
                            ("az", "Azerbaijani"),
                            ("bg", "Bulgarian"),
                            ("be", "Belarusian"),
                            ("bn", "Bengali"),
                            ("br", "Breton"),
                            ("bs", "Bosnian"),
                            ("ca", "Catalan"),
                            ("cs", "Czech"),
                            ("cy", "Welsh"),
                            ("da", "Danish"),
                            ("de", "German"),
                            ("dsb", "Lower Sorbian"),
                            ("el", "Greek"),
                            ("en", "English"),
                            ("en-au", "Australian English"),
                            ("en-gb", "British English"),
                            ("eo", "Esperanto"),
                            ("es", "Spanish"),
                            ("es-ar", "Argentinian Spanish"),
                            ("es-co", "Colombian Spanish"),
                            ("es-mx", "Mexican Spanish"),
                            ("es-ni", "Nicaraguan Spanish"),
                            ("es-ve", "Venezuelan Spanish"),
                            ("et", "Estonian"),
                            ("eu", "Basque"),
                            ("fa", "Persian"),
                            ("fi", "Finnish"),
                            ("fr", "French"),
                            ("fy", "Frisian"),
                            ("ga", "Irish"),
                            ("gd", "Scottish Gaelic"),
                            ("gl", "Galician"),
                            ("he", "Hebrew"),
                            ("hi", "Hindi"),
                            ("hr", "Croatian"),
                            ("hsb", "Upper Sorbian"),
                            ("hu", "Hungarian"),
                            ("hy", "Armenian"),
                            ("ia", "Interlingua"),
                            ("id", "Indonesian"),
                            ("ig", "Igbo"),
                            ("io", "Ido"),
                            ("is", "Icelandic"),
                            ("it", "Italian"),
                            ("ja", "Japanese"),
                            ("ka", "Georgian"),
                            ("kab", "Kabyle"),
                            ("kk", "Kazakh"),
                            ("km", "Khmer"),
                            ("kn", "Kannada"),
                            ("ko", "Korean"),
                            ("ky", "Kyrgyz"),
                            ("lb", "Luxembourgish"),
                            ("lt", "Lithuanian"),
                            ("lv", "Latvian"),
                            ("mk", "Macedonian"),
                            ("ml", "Malayalam"),
                            ("mn", "Mongolian"),
                            ("mr", "Marathi"),
                            ("ms", "Malay"),
                            ("my", "Burmese"),
                            ("nb", "Norwegian Bokmål"),
                            ("ne", "Nepali"),
                            ("nl", "Dutch"),
                            ("nn", "Norwegian Nynorsk"),
                            ("os", "Ossetic"),
                            ("pa", "Punjabi"),
                            ("pl", "Polish"),
                            ("pt", "Portuguese"),
                            ("pt-br", "Brazilian Portuguese"),
                            ("ro", "Romanian"),
                            ("ru", "Russian"),
                            ("sk", "Slovak"),
                            ("sl", "Slovenian"),
                            ("sq", "Albanian"),
                            ("sr", "Serbian"),
                            ("sr-latn", "Serbian Latin"),
                            ("sv", "Swedish"),
                            ("sw", "Swahili"),
                            ("ta", "Tamil"),
                            ("te", "Telugu"),
                            ("tg", "Tajik"),
                            ("th", "Thai"),
                            ("tk", "Turkmen"),
                            ("tr", "Turkish"),
                            ("tt", "Tatar"),
                            ("udm", "Udmurt"),
                            ("uk", "Ukrainian"),
                            ("ur", "Urdu"),
                            ("uz", "Uzbek"),
                            ("vi", "Vietnamese"),
                            ("zh-hans", "Simplified Chinese"),
                            ("zh-hant", "Traditional Chinese"),
                        ],
                        max_length=7,
                        verbose_name="Language Code",
                    ),
                ),
                ("content", models.TextField(verbose_name="Content")),
                (
                    "encoding",
                    models.IntegerField(choices=[(1, "Markdown")], default=1, verbose_name="Encoding Format"),
                ),
                (
                    "up_vote",
                    models.IntegerField(default=0, help_text="Calculated value of all Votes", verbose_name="Up Vote"),
                ),
                (
                    "up_vote_count",
                    models.IntegerField(
                        default=0, help_text="Calculated total of Votes cast", verbose_name="Up Vote Count"
                    ),
                ),
                (
                    "state",
                    models.IntegerField(
                        choices=[(0, "Published"), (1, "Draft"), (2, "Archived")], default=1, verbose_name="State"
                    ),
                ),
                (
                    "solution",
                    models.BooleanField(
                        help_text="This will tag a comment as an accepted solution if used.", verbose_name="Solution"
                    ),
                ),
                (
                    "author",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_comments",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
                (
                    "parent",
                    models.ForeignKey(
                        blank=True,
                        help_text="For threading comments, no parent is a top level comment",
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="children",
                        to="blogorama.comment",
                        verbose_name="Parent",
                    ),
                ),
            ],
            options={
                "verbose_name": "Comment",
                "verbose_name_plural": "Comments",
                "ordering": ("up_vote", "created"),
            },
        ),
        migrations.CreateModel(
            name="Post",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("uuid", models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ("created", models.DateField(auto_now_add=True, verbose_name="Created")),
                ("updated", models.DateField(auto_now=True, verbose_name="Updated")),
                ("title", models.CharField(help_text="Headline for the post.", max_length=120, verbose_name="Title")),
                ("slug", models.SlugField(blank=True, verbose_name="Slug")),
                ("release_date", models.DateField(auto_now_add=True, verbose_name="Updated")),
                (
                    "banner_image",
                    models.ImageField(
                        blank=True,
                        height_field=1200,
                        max_length=1800,
                        null=True,
                        upload_to="blog/post/",
                        verbose_name="Banner",
                        width_field=1800,
                    ),
                ),
                (
                    "banner_alt",
                    models.CharField(blank=True, max_length=125, null=True, verbose_name="Banner Alt Tag String"),
                ),
                (
                    "language",
                    models.CharField(
                        choices=[
                            ("af", "Afrikaans"),
                            ("ar", "Arabic"),
                            ("ar-dz", "Algerian Arabic"),
                            ("ast", "Asturian"),
                            ("az", "Azerbaijani"),
                            ("bg", "Bulgarian"),
                            ("be", "Belarusian"),
                            ("bn", "Bengali"),
                            ("br", "Breton"),
                            ("bs", "Bosnian"),
                            ("ca", "Catalan"),
                            ("cs", "Czech"),
                            ("cy", "Welsh"),
                            ("da", "Danish"),
                            ("de", "German"),
                            ("dsb", "Lower Sorbian"),
                            ("el", "Greek"),
                            ("en", "English"),
                            ("en-au", "Australian English"),
                            ("en-gb", "British English"),
                            ("eo", "Esperanto"),
                            ("es", "Spanish"),
                            ("es-ar", "Argentinian Spanish"),
                            ("es-co", "Colombian Spanish"),
                            ("es-mx", "Mexican Spanish"),
                            ("es-ni", "Nicaraguan Spanish"),
                            ("es-ve", "Venezuelan Spanish"),
                            ("et", "Estonian"),
                            ("eu", "Basque"),
                            ("fa", "Persian"),
                            ("fi", "Finnish"),
                            ("fr", "French"),
                            ("fy", "Frisian"),
                            ("ga", "Irish"),
                            ("gd", "Scottish Gaelic"),
                            ("gl", "Galician"),
                            ("he", "Hebrew"),
                            ("hi", "Hindi"),
                            ("hr", "Croatian"),
                            ("hsb", "Upper Sorbian"),
                            ("hu", "Hungarian"),
                            ("hy", "Armenian"),
                            ("ia", "Interlingua"),
                            ("id", "Indonesian"),
                            ("ig", "Igbo"),
                            ("io", "Ido"),
                            ("is", "Icelandic"),
                            ("it", "Italian"),
                            ("ja", "Japanese"),
                            ("ka", "Georgian"),
                            ("kab", "Kabyle"),
                            ("kk", "Kazakh"),
                            ("km", "Khmer"),
                            ("kn", "Kannada"),
                            ("ko", "Korean"),
                            ("ky", "Kyrgyz"),
                            ("lb", "Luxembourgish"),
                            ("lt", "Lithuanian"),
                            ("lv", "Latvian"),
                            ("mk", "Macedonian"),
                            ("ml", "Malayalam"),
                            ("mn", "Mongolian"),
                            ("mr", "Marathi"),
                            ("ms", "Malay"),
                            ("my", "Burmese"),
                            ("nb", "Norwegian Bokmål"),
                            ("ne", "Nepali"),
                            ("nl", "Dutch"),
                            ("nn", "Norwegian Nynorsk"),
                            ("os", "Ossetic"),
                            ("pa", "Punjabi"),
                            ("pl", "Polish"),
                            ("pt", "Portuguese"),
                            ("pt-br", "Brazilian Portuguese"),
                            ("ro", "Romanian"),
                            ("ru", "Russian"),
                            ("sk", "Slovak"),
                            ("sl", "Slovenian"),
                            ("sq", "Albanian"),
                            ("sr", "Serbian"),
                            ("sr-latn", "Serbian Latin"),
                            ("sv", "Swedish"),
                            ("sw", "Swahili"),
                            ("ta", "Tamil"),
                            ("te", "Telugu"),
                            ("tg", "Tajik"),
                            ("th", "Thai"),
                            ("tk", "Turkmen"),
                            ("tr", "Turkish"),
                            ("tt", "Tatar"),
                            ("udm", "Udmurt"),
                            ("uk", "Ukrainian"),
                            ("ur", "Urdu"),
                            ("uz", "Uzbek"),
                            ("vi", "Vietnamese"),
                            ("zh-hans", "Simplified Chinese"),
                            ("zh-hant", "Traditional Chinese"),
                        ],
                        max_length=7,
                        verbose_name="Language Code",
                    ),
                ),
                ("content", models.TextField(verbose_name="Content")),
                (
                    "encoding_format",
                    models.IntegerField(choices=[(1, "Markdown")], default=1, verbose_name="Encoding Format"),
                ),
                (
                    "state",
                    models.IntegerField(
                        choices=[(0, "Published"), (1, "Draft"), (2, "Archived")],
                        default=1,
                        help_text="What state is the writing in?",
                        verbose_name="State",
                    ),
                ),
                (
                    "active",
                    models.BooleanField(
                        help_text="Auto managed field based on state criteria when saved.", verbose_name="Active"
                    ),
                ),
                ("rating", models.IntegerField(default=0, verbose_name="Rating")),
                ("rating_count", models.IntegerField(default=0, verbose_name="Rating Count")),
                (
                    "sticky",
                    models.IntegerField(
                        default=0,
                        help_text="Give the blog posts a sticky value to sort to the top of the list of posts.  Higher value becomes higher in the list.",
                        verbose_name="Sticky",
                    ),
                ),
                ("locked", models.BooleanField(help_text="Can not add Comments and Replies.", verbose_name="Locked")),
                (
                    "hide_responses",
                    models.BooleanField(help_text="Hide responses in display.", verbose_name="Hide Responses"),
                ),
                (
                    "author",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_posts",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
                (
                    "parent",
                    models.ForeignKey(
                        blank=True,
                        help_text="For detailed responses for use in How-To support threads.  Not used in Blogs.",
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="responses",
                        to="blogorama.post",
                        verbose_name="Parent",
                    ),
                ),
                (
                    "sites",
                    models.ManyToManyField(help_text="Set which sites this post is available on", to="sites.site"),
                ),
            ],
            options={
                "verbose_name": "Post",
                "verbose_name_plural": "Posts",
                "ordering": ("sticky", "created"),
            },
        ),
        migrations.CreateModel(
            name="Tag",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(max_length=50, verbose_name="Tag Name")),
                (
                    "language",
                    models.CharField(
                        choices=[
                            ("af", "Afrikaans"),
                            ("ar", "Arabic"),
                            ("ar-dz", "Algerian Arabic"),
                            ("ast", "Asturian"),
                            ("az", "Azerbaijani"),
                            ("bg", "Bulgarian"),
                            ("be", "Belarusian"),
                            ("bn", "Bengali"),
                            ("br", "Breton"),
                            ("bs", "Bosnian"),
                            ("ca", "Catalan"),
                            ("cs", "Czech"),
                            ("cy", "Welsh"),
                            ("da", "Danish"),
                            ("de", "German"),
                            ("dsb", "Lower Sorbian"),
                            ("el", "Greek"),
                            ("en", "English"),
                            ("en-au", "Australian English"),
                            ("en-gb", "British English"),
                            ("eo", "Esperanto"),
                            ("es", "Spanish"),
                            ("es-ar", "Argentinian Spanish"),
                            ("es-co", "Colombian Spanish"),
                            ("es-mx", "Mexican Spanish"),
                            ("es-ni", "Nicaraguan Spanish"),
                            ("es-ve", "Venezuelan Spanish"),
                            ("et", "Estonian"),
                            ("eu", "Basque"),
                            ("fa", "Persian"),
                            ("fi", "Finnish"),
                            ("fr", "French"),
                            ("fy", "Frisian"),
                            ("ga", "Irish"),
                            ("gd", "Scottish Gaelic"),
                            ("gl", "Galician"),
                            ("he", "Hebrew"),
                            ("hi", "Hindi"),
                            ("hr", "Croatian"),
                            ("hsb", "Upper Sorbian"),
                            ("hu", "Hungarian"),
                            ("hy", "Armenian"),
                            ("ia", "Interlingua"),
                            ("id", "Indonesian"),
                            ("ig", "Igbo"),
                            ("io", "Ido"),
                            ("is", "Icelandic"),
                            ("it", "Italian"),
                            ("ja", "Japanese"),
                            ("ka", "Georgian"),
                            ("kab", "Kabyle"),
                            ("kk", "Kazakh"),
                            ("km", "Khmer"),
                            ("kn", "Kannada"),
                            ("ko", "Korean"),
                            ("ky", "Kyrgyz"),
                            ("lb", "Luxembourgish"),
                            ("lt", "Lithuanian"),
                            ("lv", "Latvian"),
                            ("mk", "Macedonian"),
                            ("ml", "Malayalam"),
                            ("mn", "Mongolian"),
                            ("mr", "Marathi"),
                            ("ms", "Malay"),
                            ("my", "Burmese"),
                            ("nb", "Norwegian Bokmål"),
                            ("ne", "Nepali"),
                            ("nl", "Dutch"),
                            ("nn", "Norwegian Nynorsk"),
                            ("os", "Ossetic"),
                            ("pa", "Punjabi"),
                            ("pl", "Polish"),
                            ("pt", "Portuguese"),
                            ("pt-br", "Brazilian Portuguese"),
                            ("ro", "Romanian"),
                            ("ru", "Russian"),
                            ("sk", "Slovak"),
                            ("sl", "Slovenian"),
                            ("sq", "Albanian"),
                            ("sr", "Serbian"),
                            ("sr-latn", "Serbian Latin"),
                            ("sv", "Swedish"),
                            ("sw", "Swahili"),
                            ("ta", "Tamil"),
                            ("te", "Telugu"),
                            ("tg", "Tajik"),
                            ("th", "Thai"),
                            ("tk", "Turkmen"),
                            ("tr", "Turkish"),
                            ("tt", "Tatar"),
                            ("udm", "Udmurt"),
                            ("uk", "Ukrainian"),
                            ("ur", "Urdu"),
                            ("uz", "Uzbek"),
                            ("vi", "Vietnamese"),
                            ("zh-hans", "Simplified Chinese"),
                            ("zh-hant", "Traditional Chinese"),
                        ],
                        max_length=7,
                        verbose_name="Language Code",
                    ),
                ),
                ("active", models.BooleanField(verbose_name="Active")),
                (
                    "approved",
                    models.BooleanField(
                        help_text="Check if approved for use when approval is required.", verbose_name="Approved"
                    ),
                ),
                (
                    "author",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_post_tags",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
                ("posts", models.ManyToManyField(to="blogorama.post", verbose_name="Posts")),
                (
                    "related",
                    models.ManyToManyField(
                        help_text="Used to connect tags that are the same but in different languages.",
                        to="blogorama.tag",
                        verbose_name="Related",
                    ),
                ),
            ],
            options={
                "verbose_name": "Tag",
                "verbose_name_plural": "Tags",
            },
        ),
        migrations.CreateModel(
            name="Vote",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("updated", models.DateField(auto_now=True, verbose_name="Updated")),
                (
                    "upvote",
                    models.BooleanField(
                        help_text="Checked it's an up-vote, unchecked it's a down-vote", verbose_name="Up-Vote"
                    ),
                ),
                (
                    "comments",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_comment_votes",
                        to="blogorama.comment",
                        verbose_name="Comment",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_comment_votes",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
            ],
            options={
                "verbose_name": "Vote",
                "verbose_name_plural": "Votes",
            },
        ),
        migrations.CreateModel(
            name="TagSuggestion",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                (
                    "score",
                    models.IntegerField(
                        help_text="How relevent the suggested tag is to the connected tag", verbose_name="Score"
                    ),
                ),
                (
                    "suggestion",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="suggestions",
                        to="blogorama.tag",
                        verbose_name="Suggested Tag",
                    ),
                ),
                (
                    "tag",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="referrals",
                        to="blogorama.tag",
                        verbose_name="Tag",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Save",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("created", models.DateField(auto_now_add=True, verbose_name="Created")),
                (
                    "blog",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_saves",
                        to="blogorama.post",
                        verbose_name="Blog Post",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_saves",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
            ],
            options={
                "verbose_name": "Archive",
                "verbose_name_plural": "Archives",
            },
        ),
        migrations.CreateModel(
            name="Rating",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("active", models.BooleanField(verbose_name="Active")),
                ("created", models.DateField(auto_now_add=True, verbose_name="Created")),
                ("updated", models.DateField(auto_now=True, verbose_name="Updated")),
                (
                    "value",
                    models.SmallIntegerField(
                        choices=[(1, "1"), (2, "2"), (3, "3"), (4, "4"), (5, "5")],
                        default=3,
                        verbose_name="Vote Value",
                    ),
                ),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="ratings",
                        to="blogorama.post",
                        verbose_name="Blog Post",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_post_ratings",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
            ],
            options={
                "verbose_name": "Rating",
                "verbose_name_plural": "Ratings",
            },
        ),
        migrations.CreateModel(
            name="PostFlag",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("created", models.DateField(auto_now_add=True, verbose_name="Created")),
                ("updated", models.DateField(auto_now=True, verbose_name="Updated")),
                ("description", models.TextField(verbose_name="Description")),
                (
                    "issue",
                    models.IntegerField(
                        choices=[(0, "Off Topic"), (10, "Spam"), (20, "Inappropriate")],
                        default=0,
                        verbose_name="Issue",
                    ),
                ),
                (
                    "post",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="post_flags",
                        to="blogorama.post",
                        verbose_name="Post Flagged",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_post_flags",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
            ],
            options={
                "verbose_name": "Flag",
                "verbose_name_plural": "Flags",
            },
        ),
        migrations.CreateModel(
            name="Flag",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("created", models.DateField(auto_now_add=True, verbose_name="Created")),
                ("updated", models.DateField(auto_now=True, verbose_name="Updated")),
                ("description", models.TextField(verbose_name="Description")),
                (
                    "issue",
                    models.IntegerField(
                        choices=[(0, "Off Topic"), (10, "Spam"), (20, "Inappropriate")],
                        default=0,
                        verbose_name="Issue",
                    ),
                ),
                (
                    "comments",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="comment_flags",
                        to="blogorama.comment",
                        verbose_name="Comment Flagged",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_comment_flags",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
            ],
            options={
                "verbose_name": "Flag",
                "verbose_name_plural": "Flags",
            },
        ),
        migrations.CreateModel(
            name="Ban",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("description", models.TextField(help_text="Description of the ban.", verbose_name="Content")),
                ("created", models.DateField(auto_now_add=True, verbose_name="Created")),
                ("expiration", models.DateField(blank=True, null=True, verbose_name="Expiration")),
                ("indefinite", models.BooleanField(verbose_name="Indefinitely Banned")),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="blog_comment_bans",
                        to=settings.AUTH_USER_MODEL,
                        verbose_name="User",
                    ),
                ),
            ],
            options={
                "verbose_name": "Ban",
                "verbose_name_plural": "Bans",
            },
        ),
    ]



from django.contrib import admin

from .models import Post, Tag, TagSuggestion, Comment, Vote, Rating, Save, Flag, PostFlag, Ban

admin.site.register(Post)
admin.site.register(Tag)
admin.site.register(TagSuggestion)
admin.site.register(Comment)
admin.site.register(Vote)
admin.site.register(Rating)
admin.site.register(Save)
admin.site.register(Flag)
admin.site.register(PostFlag)
admin.site.register(Ban)
